@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ConfigDefs.pl 4972 2009-12-04 14:39:05Z sysjkf $
+#   $Id: ConfigDefs.pl 5028 2010-06-09 21:21:29Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -132,6 +132,7 @@ includespamheader		= alwaysincludespamassassinreport
 includemcpheader		= alwaysincludemcpreport
 infoheader			= informationheader
 infovalue			= informationheadervalue
+insistpasszips			= ArchivesMustBePasswordProtected
 inlinehtmlsig			= inlinehtmlsignature
 inlinehtmlwarning		= inlinehtmlwarning
 inlinetextsig			= inlinetextsignature
@@ -296,6 +297,7 @@ storeentireasdfqf	0	no	0	yes	1
 syntaxcheck		1	no	0	yes	1
 usedefaultswithmanyrecips	0	no	0	yes	1
 #virusbeforespammcp	0	no	0	yes	1
+SQLDebug		0	no	0	yes	1
 
 # These should be checked for dir existence
 [Simple,Dir]
@@ -407,6 +409,14 @@ VirusScanners		auto  # Space-separated list
 WorkUser
 WorkGroup
 WorkPerms		0600
+DBDSN
+DBUsername
+DBPassword
+SQLSerialNumber
+SQLQuickPeek
+SQLConfig
+SQLRuleset
+SQLSpamAssassinConfig
 
 #
 # These variables match on any rule matching From:, else anything for To:
@@ -619,6 +629,7 @@ FindPhishing		1	no	0	yes	1
 markinfectedmessages	1	no	0	yes	1
 PhishingHighlight	1	no	0	yes	1
 HtmlToText		0	no	0	yes	1
+InsistPassZips		0	no	0	yes	1
 NewHeadersAtTop		0	no	0	yes	1
 PhishingNumbers		1	no	0	yes	1
 QuarantineInfections	1	no	0	yes	1
