@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: MessageBatch.pm 4972 2009-12-04 14:39:05Z sysjkf $
+#   $Id: MessageBatch.pm 5028 2010-06-09 21:21:29Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ use DBI qw(:sql_types);
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4972 $, 10;
+$VERSION = substr q$Revision: 5028 $, 10;
 
 my $maxcleanbytes    = 0;
 my $maxcleanmessages = 0;
@@ -990,6 +990,7 @@ sub WarnLocalPostmaster {
       $reasons{sizeinfected}      = 1 if $message->{sizeinfected};
       # JKF 19/12/2007 $reasons{passwordinfected}  = 1 if $message->{passwordinfected};
       $reasons{passwordprotected} = 1 if $message->{passwordprotected};
+      $reasons{nonpasswordprotected} = 1 if $message->{nonpasswordprotected};
       foreach $thisreason (sort keys %reasons) {
         $reasons .= " : " if $reasons ne "";
         $reasons .= MailScanner::Config::LanguageValue($message, "notice" .
@@ -1208,7 +1209,7 @@ sub CreateEicarBatch {
   # Message number = 1
   # Path = irrelevant as we're not actually reading anything
   # It's a fake that we simulate ==> 1
-  my $MessageDir = tempdir( 'MSlintXXXXXX', CLEANUP => 1);
+  my $MessageDir = tempdir( 'MSlintXXXXXX', TMPDIR => 1, CLEANUP => 1);
   my $newmessage = MailScanner::Message->new(1, $MessageDir, 0, 1);
   @{$newmessage->{headers}} = ();
   @{$newmessage->{to}} = ();
