@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SweepOther.pm 4714 2009-04-01 16:12:10Z sysjkf $
+#   $Id: SweepOther.pm 5011 2010-04-22 16:12:43Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ use POSIX qw(:signal_h setsid); # For Solaris 9 SIG bug workaround
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4714 $, 10;
+$VERSION = substr q$Revision: 5011 $, 10;
 
 # Attributes are
 #
@@ -230,6 +230,7 @@ sub ScanBatch {
         $notypesafename = substr($safename,1);
         # TNEF winmail.dat will always be a normal attachment.
         $attach = $message->{safefile2file}{$safename} || $tnefname;
+        #print STDERR "Attachment name safefile2file($safename) = $attach\n";
         next if $attach eq "" && $safename eq "";
         $TypeIndicator = substr($safename,0,1);
 
@@ -407,7 +408,8 @@ sub CheckFileContentTypes {
       # Only process the output if we are scanning, not disinfecting
       while(<$Kid>) {
         chomp;
-        $FileTypes{$1}{$2} = $3 if /^([^\/]+)\/([^:]+):\s*(.*)$/;
+        #$FileTypes{$1}{$2} = $3 if /^([^\/]+)\/([^:]+):\s*(.*)$/;
+        $FileTypes{$1}{$2} = $3 if /^([^\/]+)\/([^:]+):\s*([^,]*)/;
         #print STDERR "Processing line \"$_\"\n";
       }
       close $Kid;
@@ -427,7 +429,7 @@ sub CheckFileContentTypes {
       @filelist = <*/*>;
       exit 0 unless @filelist;
       #exec "$filecommand */*"; # Shouldn't do this like this!
-      exec(split(/ +/, $filecommand), @filelist);
+      exec(map { m/(.*)/ } split(/ +/, $filecommand), @filelist);
       MailScanner::Log::WarnLog("Can't run file command " .
                                 "(\"$filecommand\"): $!");
       exit 1;
@@ -507,7 +509,7 @@ sub CheckFileContentTypes {
       @filelist = <*/*>;
       exit 0 unless @filelist;
       #exec "$filecommand */*"; # Shouldn't do this like this!
-      exec(split(/ +/, $filecommand), '-i', @filelist);
+      exec(map { m/(.*)/ } split(/ +/, $filecommand), '-i', @filelist);
       MailScanner::Log::WarnLog("Can't run 'file -i' command " .
                                 "(\"$filecommand -i\"): $!");
       exit 1;
